==> igniteui-react-inputs-18.1.2.tgz: package/esm5/lib/igr-x-icon.js <==
import { __extends, __values } from "tslib";
import * as React from 'react';
import { XIcon } from "./XIcon";
import { brushToString, stringToBrush, ensureBool, initializePropertiesFromCss, NamePatcher, isValidProp, toSpinal, getModifiedProps } from "igniteui-react-core";
import { FontInfo } from "igniteui-react-core";
import { ReactRenderer, PortalManager } from "igniteui-react-core";
var IgrXIcon = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(IgrXIcon, _super);
    function IgrXIcon(props) {
        var _this = _super.call(this, props) || this;
        _this._wrapper = null;
        _this._implementation = null;
        _this.__p = null;
        _this._hasUserValues = new Set();
        _this._stylingContainer = null;
        _this._stylingParent = null;
        _this._inStyling = false;
        if (_this._styling) {
            NamePatcher.ensureStylablePatched(Object.getPrototypeOf(_this));
        }
        _this._implementation = _this.createImplementation();
        _this._implementation.externalObject = _this;
        _this._getMainRef = _this._getMainRef.bind(_this);
        var container;
        if (document) {
            container = document.createElement("div");
        }
        var root;
        root = container;
        if (container != null) {
            root = container;
        }
        _this.requestRender = _this.requestRender.bind(_this);
        _this._portalManager = new PortalManager("iconContent", _this.requestRender);
        var ren = new ReactRenderer(root, document, true, {}, _this._portalManager);
        _this._wrapper = ren;
        _this._container = _this._wrapper.rootWrapper;
        _this._container.setStyleProperty("display", "inline-block");
        _this._container.setStyleProperty("vertical-align", "middle");
        var icon = _this.i;
        _this._icon = icon;
        icon.provideContainer(ren);
        if (props) {
            _this.initializeProperties();
        }
        return _this;
    }
    IgrXIcon.prototype._getMainRef = function (ref) {
        this._elRef = ref;
    };
    IgrXIcon.prototype.render = function () {
        var propChildren = this.props.children;
        var children = [];
        React.Children.forEach(propChildren, function (ch) {
            children.push(React.cloneElement(ch));
        });
        this._portalManager.onRender(children);
        var div = React.createElement("div", {
            className: "ig-x-icon igr-x-icon",
            ref: this._getMainRef,
            children: children
        });
        return div;
    };
    IgrXIcon.prototype.requestRender = function () {
        if (this._initialized) {
            this.setState({});
        }
    };
    //private _getLabelPortal(element: DomWrapper, portalCallback: (portal: DomPortal) => void): void {
    //    this._portalManager.getPortal(element, "TemplateContent", portalCallback);
    //}
    IgrXIcon.prototype.shouldComponentUpdate = function (nextProps, nextState) {
        var e_1, _a;
        var mod = getModifiedProps(this.props, nextProps);
        try {
            for (var _b = __values(Object.keys(mod)), _c = _b.next(); !_c.done; _c = _b.next()) {
                var p = _c.value;
                if (isValidProp(this, p)) {
                    this[p] = mod[p];
                }
            }
        }
        catch (e_1_1) {
            e_1 = { error: e_1_1 };
        }
        finally {
            try {
                if (_c && !_c.done && (_a = _b.return))
                    _a.call(_b);
            }
            finally {
                if (e_1)
                    throw e_1.error;
            }
        }
        return true;
    };
    IgrXIcon.prototype.initializeProperties = function () {
        var e_2, _a;
        try {
            for (var _b = __values(Object.keys(this.props)), _c = _b.next(); !_c.done; _c = _b.next()) {
                var p = _c.value;
                if (isValidProp(this, p)) {
                    this[p] = this.props[p];
                }
            }
        }
        catch (e_2_1) {
            e_2 = { error: e_2_1 };
        }
        finally {
            try {
                if (_c && !_c.done && (_a = _b.return))
                    _a.call(_b);
            }
            finally {
                if (e_2)
                    throw e_2.error;
            }
        }
    };
    // supports angular themes or custom properties set in CSS
    IgrXIcon.prototype.updateStyle = function () {
        this._styling(this._elRef, this);
    };
    IgrXIcon.prototype.destroy = function () {
        this._icon.destroy();
        this._wrapper.destroy();
    };
    IgrXIcon.prototype.componentWillUnmount = function () {
    };
    IgrXIcon.prototype.componentDidMount = function () {
        this._elRef.appendChild(this._container.getNativeElement());
        this.initializeContent();
    };
    IgrXIcon.prototype.initializeContent = function () {
        this._styling(this._container.getNativeElement(), this);
        this.updateStyle();
    };
    IgrXIcon.prototype.createImplementation = function () {
        return new XIcon();
    };
    Object.defineProperty(IgrXIcon.prototype, "i", {
        get: function () {
            return this._implementation;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrXIcon.prototype, "actualFill", {
        /**
     * Gets the color to use for the actual background.
    */
        get: function () {
            return brushToString(this.i.bu);
        },
        set: function (v) {
            this.i.bu = stringToBrush(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrXIcon.prototype, "actualTextColor", {
        /**
         * Gets the color to use for the actual text color.
        */
        get: function () {
            return brushToString(this.i.by);
        },
        set: function (v) {
            this.i.by = stringToBrush(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrXIcon.prototype, "actualHoverFill", {
        /**
         * Gets the color to use for the actual background.
        */
        get: function () {
            return brushToString(this.i.bv);
        },
        set: function (v) {
            this.i.bv = stringToBrush(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrXIcon.prototype, "actualHoverStroke", {
        /**
         * Gets the hover stroke to use for the icon.
        */
        get: function () {
            return brushToString(this.i.bw);
        },
        set: function (v) {
            this.i.bw = stringToBrush(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrXIcon.prototype, "actualStroke", {
        /**
         * Gets the stroke to use for the icon.
        */
        get: function () {
            return brushToString(this.i.bx);
        },
        set: function (v) {
            this.i.bx = stringToBrush(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrXIcon.prototype, "actualHoverStrokeThickness", {
        /**
         * Gets the hover stroke to use for the icon.
        */
        get: function () {
            return this.i.s;
        },
        set: function (v) {
            this.i.s = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrXIcon.prototype, "actualStrokeThickness", {
        /**
         * Gets the stroke to use for the icon.
        */
        get: function () {
            return this.i.t;
        },
        set: function (v) {
            this.i.t = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrXIcon.prototype, "fill", {
        /**
         * Gets or sets the color to use for the actual background.
        */
        get: function () {
            return brushToString(this.i.fill);
        },
        set: function (v) {
            this.i.fill = stringToBrush(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrXIcon.prototype, "textColor", {
        /**
         * Gets or sets the color to use for the text.
        */
        get: function () {
            return brushToString(this.i.b8);
        },
        set: function (v) {
            this.i.b8 = stringToBrush(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrXIcon.prototype, "svgPath", {
        /**
         * Gets or sets the color to use for the text.
        */
        get: function () {
            return this.i.svgPath;
        },
        set: function (v) {
            this.i.svgPath = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrXIcon.prototype, "hoverFill", {
        /**
         * Gets or sets the color to use for the actual background.
        */
        get: function () {
            return brushToString(this.i.b4);
        },
        set: function (v) {
            this.i.b4 = stringToBrush(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrXIcon.prototype, "hoverStroke", {
        /**
         * Gets or sets the hover stroke to use for the icon.
        */
        get: function () {
            return brushToString(this.i.b5);
        },
        set: function (v) {
            this.i.b5 = stringToBrush(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrXIcon.prototype, "stroke", {
        /**
         * Gets or sets the stroke to use for the icon.
        */
        get: function () {
            return brushToString(this.i.b7);
        },
        set: function (v) {
            this.i.b7 = stringToBrush(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrXIcon.prototype, "hoverStrokeThickness", {
        /**
         * Gets or sets the hover stroke to use for the icon.
        */
        get: function () {
            return this.i.w;
        },
        set: function (v) {
            this.i.w = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrXIcon.prototype, "strokeThickness", {
        /**
         * Gets or sets the stroke to use for the icon.
        */
        get: function () {
            return this.i.y;
        },
        set: function (v) {
            this.i.y = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrXIcon.prototype, "textStyle", {
        /**
         * Gets or sets the use for the button.
        */
        get: function () {
            if (this.i.e == null) {
                return null;
            }
            return this.i.e.fontString;
        },
        set: function (v) {
            var fi = new FontInfo();
            fi.fontString = v;
            this.i.e = fi;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrXIcon.prototype, "hoverTextColor", {
        /**
         * Gets or sets the color to use for the hovered text of the button regardless of type.
        */
        get: function () {
            return brushToString(this.i.b6);
        },
        set: function (v) {
            this.i.b6 = stringToBrush(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrXIcon.prototype, "id", {
        /**
         * Gets or sets the id to use for the checkbox.
        */
        get: function () {
            return this.i.av;
        },
        set: function (v) {
            this.i.av = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrXIcon.prototype, "tabIndex", {
        /**
         * Gets or sets TabIndex to use for the checkbox.
        */
        get: function () {
            return this.i.aa;
        },
        set: function (v) {
            this.i.aa = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrXIcon.prototype, "ariaLabel", {
        /**
         * Gets or sets the value of the aria-label attribute.
        */
        get: function () {
            return this.i.an;
        },
        set: function (v) {
            this.i.an = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrXIcon.prototype, "isHover", {
        /**
         * Gets or sets whether the icon is hovered.
        */
        get: function () {
            return this.i.l;
        },
        set: function (v) {
            this.i.l = ensureBool(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrXIcon.prototype, "disabled", {
        /**
         * Gets or sets whether the checkbox is disabled.
        */
        get: function () {
            return this.i.disabled;
        },
        set: function (v) {
            this.i.disabled = ensureBool(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrXIcon.prototype, "opacity", {
        get: function () {
            return this.i.x;
        },
        set: function (v) {
            this.i.x = +v;
        },
        enumerable: false,
        configurable: true
    });
    IgrXIcon.prototype.findByName = function (name) {
        if (this.findEphemera) {
            if (name && name.indexOf("@@e:") == 0) {
                return this.findEphemera(name);
            }
        }
        return null;
    };
    Object.defineProperty(IgrXIcon.prototype, "hasUserValues", {
        get: function () {
            return this._hasUserValues;
        },
        enumerable: false,
        configurable: true
    });
    IgrXIcon.prototype.__m = function (propertyName) {
        if (!this._inStyling) {
            this._hasUserValues.add(propertyName);
        }
    };
    IgrXIcon.prototype._styling = function (container, component, parent) {
        if (this._inStyling) {
            return;
        }
        this._inStyling = true;
        this._stylingContainer = container;
        this._stylingParent = component;
        var genericPrefix = "";
        var typeName = this.i.$type.name;
        if (typeName.indexOf("Xam") === 0) {
            typeName = typeName.substring(3);
        }
        genericPrefix = toSpinal("XIcon");
        var additionalPrefixes = [];
        var prefix = toSpinal(typeName);
        additionalPrefixes.push(prefix + "-");
        var b = this.i.$type.baseType;
        while (b && b.name != "Object" &&
            b.name != "Base" &&
            b.name != "Control" &&
            b.Name != "DependencyObject" &&
            b.Name != "FrameworkElement") {
            typeName = b.name;
            if (typeName.indexOf("Xam") === 0) {
                typeName = typeName.substring(3);
            }
            var basePrefix = toSpinal(typeName);
            additionalPrefixes.push(basePrefix + "-");
            b = b.baseType;
        }
        if (parent) {
            var parentTypeName = parent.i.$type.name;
            if (parentTypeName.indexOf("Xam") === 0) {
                parentTypeName = parentTypeName.substring(3);
            }
            var parentPrefix = toSpinal(parentTypeName);
            additionalPrefixes.push(parentPrefix + "-" + genericPrefix + "-");
            additionalPrefixes.push(parentPrefix + "-" + prefix + "-");
        }
        initializePropertiesFromCss(container, this, genericPrefix + "-", this.hasUserValues, false, additionalPrefixes);
        if (this._otherStyling) {
            this._otherStyling(container, component, parent);
        }
        this._inStyling = false;
    };
    IgrXIcon.prototype.onDetachedFromUI = function () {
        this.i.onDetachedFromUI();
    };
    IgrXIcon.prototype.onAttachedToUI = function () {
        this.i.onAttachedToUI();
    };
    /**
     * Exports visual information about the current state of the grid.
    
    */
    IgrXIcon.prototype.exportVisualModel = function () {
        var iv = this.i.ac();
        return (iv);
    };
    /**
     * Returns a serialized copy of the exported visual model
    
    */
    IgrXIcon.prototype.exportSerializedVisualModel = function () {
        var iv = this.i.ap();
        return (iv);
    };
    return IgrXIcon;
}(React.Component));
export { IgrXIcon };

==> igniteui-react-inputs-18.1.3.tgz: package/esm5/lib/igr-x-icon.js <==
import { __extends, __values } from "tslib";
import * as React from 'react';
import { XIcon } from "./XIcon";
import { ensureEnum, brushToString, stringToBrush, ensureBool, initializePropertiesFromCss, NamePatcher, isValidProp, toSpinal, getModifiedProps } from "igniteui-react-core";
import { FontInfo } from "igniteui-react-core";
import { ReactRenderer, PortalManager } from "igniteui-react-core";
import { BaseControlTheme_$type } from "igniteui-react-core";
var IgrXIcon = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(IgrXIcon, _super);
    function IgrXIcon(props) {
        var _this = _super.call(this, props) || this;
        _this._wrapper = null;
        _this._implementation = null;
        _this.__p = null;
        _this._hasUserValues = new Set();
        _this._stylingContainer = null;
        _this._stylingParent = null;
        _this._inStyling = false;
        if (_this._styling) {
            NamePatcher.ensureStylablePatched(Object.getPrototypeOf(_this));
        }
        _this._implementation = _this.createImplementation();
        _this._implementation.externalObject = _this;
        _this._getMainRef = _this._getMainRef.bind(_this);
        var container;
        if (document) {
            container = document.createElement("div");
        }
        var root;
        root = container;
        if (container != null) {
            root = container;
        }
        _this.requestRender = _this.requestRender.bind(_this);
        _this._portalManager = new PortalManager("iconContent", _this.requestRender);
        var ren = new ReactRenderer(root, document, true, {}, _this._portalManager);
        _this._wrapper = ren;
        _this._container = _this._wrapper.rootWrapper;
        _this._container.setStyleProperty("display", "inline-block");
        _this._container.setStyleProperty("vertical-align", "middle");
        var icon = _this.i;
        _this._icon = icon;
        icon.provideContainer(ren);
        if (props) {
            _this.initializeProperties();
        }
        return _this;
    }
    IgrXIcon.prototype._getMainRef = function (ref) {
        this._elRef = ref;
    };
    IgrXIcon.prototype.render = function () {
        var propChildren = this.props.children;
        var children = [];
        React.Children.forEach(propChildren, function (ch) {
            children.push(React.cloneElement(ch));
        });
        this._portalManager.onRender(children);
        var div = React.createElement("div", {
            className: "ig-x-icon igr-x-icon",
            ref: this._getMainRef,
            children: children
        });
        return div;
    };
    IgrXIcon.prototype.requestRender = function () {
        if (this._initialized) {
            this.setState({});
        }
    };
    //private _getLabelPortal(element: DomWrapper, portalCallback: (portal: DomPortal) => void): void {
    //    this._portalManager.getPortal(element, "TemplateContent", portalCallback);
    //}
    IgrXIcon.prototype.shouldComponentUpdate = function (nextProps, nextState) {
        var e_1, _a;
        var mod = getModifiedProps(this.props, nextProps);
        try {
            for (var _b = __values(Object.keys(mod)), _c = _b.next(); !_c.done; _c = _b.next()) {
                var p = _c.value;
                if (isValidProp(this, p)) {
                    this[p] = mod[p];
                }
            }
        }
        catch (e_1_1) {
            e_1 = { error: e_1_1 };
        }
        finally {
            try {
                if (_c && !_c.done && (_a = _b.return))
                    _a.call(_b);
            }
            finally {
                if (e_1)
                    throw e_1.error;
            }
        }
        return true;
    };
    IgrXIcon.prototype.initializeProperties = function () {
        var e_2, _a;
        try {
            for (var _b = __values(Object.keys(this.props)), _c = _b.next(); !_c.done; _c = _b.next()) {
                var p = _c.value;
                if (isValidProp(this, p)) {
                    this[p] = this.props[p];
                }
            }
        }
        catch (e_2_1) {
            e_2 = { error: e_2_1 };
        }
        finally {
            try {
                if (_c && !_c.done && (_a = _b.return))
                    _a.call(_b);
            }
            finally {
                if (e_2)
                    throw e_2.error;
            }
        }
    };
    // supports angular themes or custom properties set in CSS
    IgrXIcon.prototype.updateStyle = function () {
        this._styling(this._elRef, this);
    };
    IgrXIcon.prototype.destroy = function () {
        this._icon.destroy();
        this._wrapper.destroy();
    };
    IgrXIcon.prototype.componentWillUnmount = function () {
    };
    IgrXIcon.prototype.componentDidMount = function () {
        this._elRef.appendChild(this._container.getNativeElement());
        this.initializeContent();
    };
    IgrXIcon.prototype.initializeContent = function () {
        this._styling(this._container.getNativeElement(), this);
        this.updateStyle();
    };
    IgrXIcon.prototype.createImplementation = function () {
        return new XIcon();
    };
    Object.defineProperty(IgrXIcon.prototype, "i", {
        get: function () {
            return this._implementation;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrXIcon.prototype, "baseTheme", {
        /**
     * Gets or sets the base built in theme to use for the button.
    */
        get: function () {
            return this.i.e;
        },
        set: function (v) {
            this.i.e = ensureEnum(BaseControlTheme_$type, v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrXIcon.prototype, "actualFill", {
        /**
         * Gets the color to use for the actual background.
        */
        get: function () {
            return brushToString(this.i.bx);
        },
        set: function (v) {
            this.i.bx = stringToBrush(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrXIcon.prototype, "actualTextColor", {
        /**
         * Gets the color to use for the actual text color.
        */
        get: function () {
            return brushToString(this.i.b1);
        },
        set: function (v) {
            this.i.b1 = stringToBrush(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrXIcon.prototype, "actualHoverFill", {
        /**
         * Gets the color to use for the actual background.
        */
        get: function () {
            return brushToString(this.i.by);
        },
        set: function (v) {
            this.i.by = stringToBrush(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrXIcon.prototype, "actualHoverStroke", {
        /**
         * Gets the hover stroke to use for the icon.
        */
        get: function () {
            return brushToString(this.i.bz);
        },
        set: function (v) {
            this.i.bz = stringToBrush(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrXIcon.prototype, "actualStroke", {
        /**
         * Gets the stroke to use for the icon.
        */
        get: function () {
            return brushToString(this.i.b0);
        },
        set: function (v) {
            this.i.b0 = stringToBrush(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrXIcon.prototype, "actualHoverStrokeThickness", {
        /**
         * Gets the hover stroke to use for the icon.
        */
        get: function () {
            return this.i.u;
        },
        set: function (v) {
            this.i.u = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrXIcon.prototype, "actualStrokeThickness", {
        /**
         * Gets the stroke to use for the icon.
        */
        get: function () {
            return this.i.v;
        },
        set: function (v) {
            this.i.v = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrXIcon.prototype, "fill", {
        /**
         * Gets or sets the color to use for the actual background.
        */
        get: function () {
            return brushToString(this.i.fill);
        },
        set: function (v) {
            this.i.fill = stringToBrush(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrXIcon.prototype, "textColor", {
        /**
         * Gets or sets the color to use for the text.
        */
        get: function () {
            return brushToString(this.i.cb);
        },
        set: function (v) {
            this.i.cb = stringToBrush(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrXIcon.prototype, "svgPath", {
        /**
         * Gets or sets the color to use for the text.
        */
        get: function () {
            return this.i.svgPath;
        },
        set: function (v) {
            this.i.svgPath = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrXIcon.prototype, "hoverFill", {
        /**
         * Gets or sets the color to use for the actual background.
        */
        get: function () {
            return brushToString(this.i.b7);
        },
        set: function (v) {
            this.i.b7 = stringToBrush(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrXIcon.prototype, "hoverStroke", {
        /**
         * Gets or sets the hover stroke to use for the icon.
        */
        get: function () {
            return brushToString(this.i.b8);
        },
        set: function (v) {
            this.i.b8 = stringToBrush(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrXIcon.prototype, "stroke", {
        /**
         * Gets or sets the stroke to use for the icon.
        */
        get: function () {
            return brushToString(this.i.ca);
        },
        set: function (v) {
            this.i.ca = stringToBrush(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrXIcon.prototype, "hoverStrokeThickness", {
        /**
         * Gets or sets the hover stroke to use for the icon.
        */
        get: function () {
            return this.i.y;
        },
        set: function (v) {
            this.i.y = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrXIcon.prototype, "strokeThickness", {
        /**
         * Gets or sets the stroke to use for the icon.
        */
        get: function () {
            return this.i.aa;
        },
        set: function (v) {
            this.i.aa = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrXIcon.prototype, "textStyle", {
        /**
         * Gets or sets the use for the button.
        */
        get: function () {
            if (this.i.g == null) {
                return null;
            }
            return this.i.g.fontString;
        },
        set: function (v) {
            var fi = new FontInfo();
            fi.fontString = v;
            this.i.g = fi;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrXIcon.prototype, "hoverTextColor", {
        /**
         * Gets or sets the color to use for the hovered text of the button regardless of type.
        */
        get: function () {
            return brushToString(this.i.b9);
        },
        set: function (v) {
            this.i.b9 = stringToBrush(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrXIcon.prototype, "id", {
        /**
         * Gets or sets the id to use for the checkbox.
        */
        get: function () {
            return this.i.ay;
        },
        set: function (v) {
            this.i.ay = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrXIcon.prototype, "tabIndex", {
        /**
         * Gets or sets TabIndex to use for the checkbox.
        */
        get: function () {
            return this.i.ac;
        },
        set: function (v) {
            this.i.ac = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrXIcon.prototype, "ariaLabel", {
        /**
         * Gets or sets the value of the aria-label attribute.
        */
        get: function () {
            return this.i.ap;
        },
        set: function (v) {
            this.i.ap = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrXIcon.prototype, "isHover", {
        /**
         * Gets or sets whether the icon is hovered.
        */
        get: function () {
            return this.i.n;
        },
        set: function (v) {
            this.i.n = ensureBool(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrXIcon.prototype, "disabled", {
        /**
         * Gets or sets whether the checkbox is disabled.
        */
        get: function () {
            return this.i.disabled;
        },
        set: function (v) {
            this.i.disabled = ensureBool(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrXIcon.prototype, "opacity", {
        get: function () {
            return this.i.z;
        },
        set: function (v) {
            this.i.z = +v;
        },
        enumerable: false,
        configurable: true
    });
    IgrXIcon.prototype.findByName = function (name) {
        if (this.findEphemera) {
            if (name && name.indexOf("@@e:") == 0) {
                return this.findEphemera(name);
            }
        }
        return null;
    };
    Object.defineProperty(IgrXIcon.prototype, "hasUserValues", {
        get: function () {
            return this._hasUserValues;
        },
        enumerable: false,
        configurable: true
    });
    IgrXIcon.prototype.__m = function (propertyName) {
        if (!this._inStyling) {
            this._hasUserValues.add(propertyName);
        }
    };
    IgrXIcon.prototype._styling = function (container, component, parent) {
        if (this._inStyling) {
            return;
        }
        this._inStyling = true;
        this._stylingContainer = container;
        this._stylingParent = component;
        var genericPrefix = "";
        var typeName = this.i.$type.name;
        if (typeName.indexOf("Xam") === 0) {
            typeName = typeName.substring(3);
        }
        genericPrefix = toSpinal("XIcon");
        var additionalPrefixes = [];
        var prefix = toSpinal(typeName);
        additionalPrefixes.push(prefix + "-");
        var b = this.i.$type.baseType;
        while (b && b.name != "Object" &&
            b.name != "Base" &&
            b.name != "Control" &&
            b.Name != "DependencyObject" &&
            b.Name != "FrameworkElement") {
            typeName = b.name;
            if (typeName.indexOf("Xam") === 0) {
                typeName = typeName.substring(3);
            }
            var basePrefix = toSpinal(typeName);
            additionalPrefixes.push(basePrefix + "-");
            b = b.baseType;
        }
        if (parent) {
            var parentTypeName = parent.i.$type.name;
            if (parentTypeName.indexOf("Xam") === 0) {
                parentTypeName = parentTypeName.substring(3);
            }
            var parentPrefix = toSpinal(parentTypeName);
            additionalPrefixes.push(parentPrefix + "-" + genericPrefix + "-");
            additionalPrefixes.push(parentPrefix + "-" + prefix + "-");
        }
        initializePropertiesFromCss(container, this, genericPrefix + "-", this.hasUserValues, false, additionalPrefixes);
        if (this._otherStyling) {
            this._otherStyling(container, component, parent);
        }
        this._inStyling = false;
    };
    IgrXIcon.prototype.onDetachedFromUI = function () {
        this.i.onDetachedFromUI();
    };
    IgrXIcon.prototype.onAttachedToUI = function () {
        this.i.onAttachedToUI();
    };
    /**
     * Exports visual information about the current state of the grid.
    
    */
    IgrXIcon.prototype.exportVisualModel = function () {
        var iv = this.i.ae();
        return (iv);
    };
    /**
     * Returns a serialized copy of the exported visual model
    
    */
    IgrXIcon.prototype.exportSerializedVisualModel = function () {
        var iv = this.i.as();
        return (iv);
    };
    return IgrXIcon;
}(React.Component));
export { IgrXIcon };
